# Get object from `AnnData`: `get`

These functions offer convenient ways to move arrays and matrices from and to the GPU.

```{eval-rst}
.. module:: rapids_singlecell.get
.. currentmodule:: rapids_singlecell

.. autosummary::
    :toctree: generated

    get.aggregate
    get.anndata_to_GPU
    get.anndata_to_CPU
    get.X_to_GPU
    get.X_to_CPU
```
